@@ -1,8 +1,8 @@
 package AnyEvent::JSONRPC::Client;
 
-use Moose;
+use Any::Moose;
 
-no Moose;
+no Any::Moose;
 
 __PACKAGE__->meta->make_immutable;
 
